@@ -90,9 +90,9 @@ tidy_perf_data <- function(performance_df) {
   test_colname <- cv_colname %>%
     gsub("cv_metric_", "", .)
   return(performance_df %>%
-    dplyr::select(.data[["method"]], .data[[cv_colname]], .data[[test_colname]]) %>%
+    dplyr::select(tidyselect::all_of(c("method", cv_colname, test_colname))) %>%
     tidyr::pivot_longer(
-      cols = c(.data[[cv_colname]], .data[[test_colname]]),
+      cols = tidyselect::all_of(c(cv_colname, test_colname)),
       names_to = "metric"
     ) %>%
     dplyr::mutate(metric = dplyr::case_when(
