@@ -80,24 +80,22 @@ test_that("run_ml works for linear regression", {
 
 test_that("run_ml works for random forest with grouping & feature importance", {
   skip_on_cran()
-  expect_equal_ml_results(
-    mikropml::run_ml(otu_mini_bin,
+  skip_on_ci()
+  expect_snapshot(
+    res <- mikropml::run_ml(otu_mini_bin,
       "rf",
       outcome_colname = "dx",
       find_feature_importance = TRUE,
       seed = 2019,
       cv_times = 2,
       groups = otu_mini_group
-    ),
-    otu_mini_bin_results_rf,
-    tolerance = 1e-3
-  ) %>%
-    suppressWarnings() %>%
-    suppressMessages()
+    )
+  )
 })
 
 test_that("run_ml works for svmRadial", {
   skip_on_cran()
+  skip_on_ci()
   expect_equal_ml_results(
     mikropml::run_ml(otu_mini_bin,
       "svmRadial",
@@ -114,6 +112,7 @@ test_that("run_ml works for svmRadial", {
 
 test_that("run_ml works for xgbTree", {
   skip_on_cran()
+  skip_on_ci()
   skip_on_os(c("linux", "windows")) # bug in xgboost package: https://discuss.xgboost.ai/t/colsample-by-tree-leads-to-not-reproducible-model-across-machines-mac-os-windows/1709
   expect_equal_ml_results(
     mikropml::run_ml(
@@ -133,6 +132,7 @@ test_that("run_ml works for xgbTree", {
 
 test_that("run_ml works for rpart2", {
   skip_on_cran()
+  skip_on_ci()
   expect_equal_ml_results(
     mikropml::run_ml(otu_mini_bin,
       "rpart2",
@@ -216,8 +216,8 @@ test_that("run_ml uses custom training indices when provided", {
       seed = 2019
     )
   ) %>% suppressMessages()
-  expect_true(dplyr::all_equal(
-    results_custom_train$test_data,
+  expect_true(all.equal(
+    results_custom_train$test_data[, colnames(otu_mini_bin)],
     otu_mini_bin[-training_rows, ]
   ))
 })
@@ -244,8 +244,9 @@ test_that("run_ml uses custom group partitions", {
     group_partitions = group_part,
     training_frac = 0.8
   )
-  expect_true(dplyr::all_equal(
-    results_grp_part$test_data,
+  col_names <- colnames(otu_mini_bin)
+  expect_true(all.equal(
+    results_grp_part$test_data[, col_names],
     otu_mini_bin[-train_ind, ]
   ))
 })
@@ -263,7 +264,7 @@ test_that("run_ml catches bad training_frac values", {
     run_ml(otu_mini_bin,
       "glmnet",
       outcome_colname = "dx",
-      training_frac = 1
+      training_frac = 1.0000001
     ),
     "`training_frac` must be a numeric between 0 and 1."
   )
